@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Detalls</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Borrar</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Proposar</translation>
@@ -142,6 +138,10 @@
         <source>Discipline</source>
         <translation>Disciplina</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Compte enrrera de 30 segons i incrementa amb els encerts.</translation>
@@ -170,6 +170,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Compte enrrera de 30 segons i incrementa o disminueix amb els intents.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -289,33 +293,53 @@
         <translation>Puntuacions més altes</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nom&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Puntuació&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Nom</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Data&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Puntuació</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Temps&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Data</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Pregunta</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Borrar les puntuacions?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -443,18 +467,10 @@
         <source>&amp;About</source>
         <translation>&amp;Crèdits</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Crèdits de &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Crèdits de &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Crèdits de &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -483,14 +499,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Llista de paraules hebrea basada en &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; de Nadav Har&apos;El i Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Crèdits de Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Crèdits de SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Importar Joc</translation>
@@ -563,6 +571,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Jugar amb el ratolí:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una paraula:&lt;/b&gt; Clica sobre les lletres d&apos;una paraula.&lt;br&gt;&lt;b&gt;Fes un suggeriment:&lt;/b&gt; Clica sobre la darrera lletra seleccionada.&lt;br&gt;&lt;b&gt;Borrar lletres:&lt;/b&gt; Clica sobre una lletra seleccionada prèviament.&lt;br&gt;&lt;b&gt;Borrar la paraula:&lt;/b&gt; Clica dues vegades sobre la primera lletra seleccionada.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Jugar amb el teclat:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una paraula:&lt;/b&gt; Tecleja les lletres d&apos;una paraula.&lt;br&gt;&lt;b&gt;Fes una suggerencia:&lt;/b&gt; Presiona Enter.&lt;br&gt;&lt;b&gt;Borra la paraula:&lt;/b&gt; Presiona Ctrl+Espai.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
