@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Подробности</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Очистить</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Угадать</translation>
@@ -150,6 +146,10 @@
         <source>Discipline</source>
         <translation>Тренировочный</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Отсчитывает 30 секунд и увеличивается, если отгадано правильно</translation>
@@ -178,6 +178,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Отсчитывает 30 секунд и увеличивается или уменьшается по отгадкам.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -298,33 +302,53 @@
         <translation>Лучшие результаты</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Имя&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Результат&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Имя</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Дата&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Результат</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Таймер&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Дата</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Вопрос</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Очистить Лучшие результаты?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -452,18 +476,10 @@
         <source>&amp;About</source>
         <translation>&amp;Информация</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>О &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>О &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>О &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -492,14 +508,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Список слов на Иврите основан на &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; от Nadav Har&apos;El и Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>О Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>О SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Выбрать Игру</translation>
@@ -572,6 +580,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Игра мышкой:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Выберите слово:&lt;/b&gt; Нажмите на буквы слова.&lt;br&gt;&lt;b&gt;Угадать:&lt;/b&gt; Нажмите на последнюю выбранную букву.&lt;br&gt;&lt;b&gt;Стереть буквы:&lt;/b&gt; Нажмите на ранее выбранную букву.&lt;br&gt;&lt;b&gt;Очистить слово:&lt;/b&gt; Нажмите дважды на первую выбранную букву.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Игра на клавиатуре:&lt;/b&gt;&lt;br&gt;&lt;b&gt;Выберите слово:&lt;/b&gt; Введите буквы слова.&lt;br&gt;&lt;b&gt;Угадать:&lt;/b&gt; Нажмите Enter.&lt;br&gt;&lt;b&gt;Очистить слово:&lt;/b&gt; Нажмите Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
